@@ -174,7 +174,7 @@ static an_option_t options[] = {
     {'{', "sigma", required_argument, "float",
      "set the noise level in the image"},
     {'\x93', "nsigma", required_argument, "float",
-     "number of sigma for a source detection; default 8"},
+     "number of sigma for a source detection; default 8 for FITS images, 4 for JPEG, etc"},
     {'9', "no-remove-lines", no_argument, NULL,
      "don't remove horizontal and vertical overdensities of sources."},
     {':', "uniformize", required_argument, "int",
@@ -743,6 +743,7 @@ int augment_xylist(augment_xylist_t* axy,
                 sl_append(cmd, "--ppm");
             sl_append(cmd, "--mydir");
             append_escape(cmd, me);
+	    logmsg("Running command: %s\n", sl_join(cmd, " "));
             lines = backtick(cmd, verbose);
             axy->isfits = FALSE;
             for (i=0; i<sl_size(lines); i++) {
@@ -759,7 +760,6 @@ int augment_xylist(augment_xylist_t* axy,
             // Get image W, H, depth.
             sl_append(cmd, "pnmfile");
             append_escape(cmd, pnmfn);
-
             lines = backtick(cmd, verbose);
 
             if (sl_size(lines) == 0) {
@@ -894,6 +894,7 @@ int augment_xylist(augment_xylist_t* axy,
                 axy->ycol = "Y_IMAGE";
                 axy->sortcol = "MAG_AUTO";
                 axy->sort_ascending = TRUE;
+                axy->resort = FALSE;
 
                 filterfn = create_temp_file("filter", axy->tempdir);
                 sl_append_nocopy(tempfiles, filterfn);
