@@ -45,9 +45,9 @@ static void print_help(char* progname) {
            "                -P 10 should work for images about 4 degree across\n"
            "                 etc... up to -P 19\n"
            "  OR,\n"
-           "         -N <nside>            healpix Nside for quad-building\n"
-           "         -l <min-quad-size>    minimum quad size (arcminutes)\n"
-           "         -u <max-quad-size>    maximum quad size (arcminutes)\n"
+           "         -N <nside>            healpix Nside for quad-building (-P 0 -> -N 1760)\n"
+           "         -l <min-quad-size>    minimum quad size (arcminutes) (-P 0 -> -l 2.0)\n"
+           "         -u <max-quad-size>    maximum quad size (arcminutes) (-P 0 -> -u 2.8)\n"
            "      )\n"
            "      [-S <column>]: sort column (default: assume the input file is already sorted)\n"
            "      [-f]: sort in descending order (eg, for FLUX); default ascending (eg, for MAG)\n"
@@ -74,7 +74,7 @@ static void print_help(char* progname) {
            "\n"
            "      [-M]: in-memory (don't use temp files)\n"
            "      [-T]: don't delete temp files\n"
-           "      [-t <temp-dir>]: use this temp direcotry (default: /tmp)\n"
+           "      [-t <temp-dir>]: use this temp directory (default: /tmp)\n"
            "      [-v]: add verbosity.\n"
            "\n", progname);
 }
@@ -232,9 +232,10 @@ int main(int argc, char** argv) {
     }
 
     if (preset > -100) {
-        // I don't think we can do -6 easily (due to healpix limitations)
-        const int minpreset = -5;
-        double scales[] = { 
+        // presets of -6 and below require 64-bit healpixes
+        const int minpreset = -10;
+        double scales[] = {
+            0.06, 0.09, 0.13, 0.18, 0.25,
             0.35, 0.5, 0.7, 1., 1.4,
             2., 2.8, 4., 5.6, 8., 11., 16., 22., 30., 42., 60., 85.,
             120., 170., 240., 340., 480., 680., 1000., 1400., 2000. };
