@@ -1560,32 +1560,75 @@ anwcs_t* anwcs_create_allsky_hammer_aitoff2(double refra, double refdec,
 static anwcs_t* allsky_wcs(double refra, double refdec,
                            double zoomfactor,
                            int W, int H, anbool yflip,
-                           char* wcscode, char* wcsname) {
+                           char* wcscode, char* wcsname,
+                           anbool square_pixels,
+                           char* ctype1, char* ctype2, double rotate) {
     qfits_header* hdr;
     double xscale = -360. / (double)W;
-    double yscale =  180. / (double)H;
+    double yscale;
     char* str = NULL;
     int Nstr = 0;
     anwcs_t* anwcs = NULL;
     char code[64];
+    char ctype1str[5];
+    char ctype2str[5];
+    double cd11,cd12,cd21,cd22;
+    int i;
+    if (square_pixels)
+        yscale = xscale;
+    else
+        yscale =  180. / (double)H;
+
     if (yflip)
         yscale *= -1.;
     xscale /= zoomfactor;
     yscale /= zoomfactor;
 
+    if (ctype1 == NULL)
+        ctype1 = "RA";
+    if (ctype2 == NULL)
+        ctype2 = "DEC";
+
+    memset(ctype1str, '\0', 5);
+    memset(ctype2str, '\0', 5);
+    strncpy(ctype1str, ctype1, 4);
+    strncpy(ctype2str, ctype2, 4);
+    for (i=0; i<4; i++) {
+        if (ctype1str[i] == '\0')
+            ctype1str[i] = '-';
+        if (ctype2str[i] == '\0')
+            ctype2str[i] = '-';
+    }
+
+    if (rotate == 0.0) {
+        cd11 = xscale;
+        cd12 = cd21 = 0.;
+        cd22 = yscale;
+    } else {
+        double r = deg2rad(rotate);
+        double cr = cos(r);
+        double sr = sin(r);
+        cd11 = xscale *  cr;
+        cd12 = xscale *  sr;
+        cd21 = yscale * -sr;
+        cd22 = yscale *  cr;
+    }
+    
     hdr = qfits_header_default();
-    sprintf(code, "RA---%s", wcscode);
+    //sprintf(code, "RA---%s", wcscode);
+    sprintf(code, "%s-%s", ctype1str, wcscode);
     qfits_header_add(hdr, "CTYPE1", code, wcsname, NULL);
-    sprintf(code, "DEC--%s", wcscode);
+    //sprintf(code, "DEC--%s", wcscode);
+    sprintf(code, "%s-%s", ctype2str, wcscode);
     qfits_header_add(hdr, "CTYPE2", code, wcsname, NULL);
     fits_header_add_double(hdr, "CRPIX1", W/2. + 0.5, NULL);
     fits_header_add_double(hdr, "CRPIX2", H/2. + 0.5, NULL);
     fits_header_add_double(hdr, "CRVAL1", refra,  NULL);
     fits_header_add_double(hdr, "CRVAL2", refdec, NULL);
-    fits_header_add_double(hdr, "CD1_1", xscale, NULL);
-    fits_header_add_double(hdr, "CD1_2", 0, NULL);
-    fits_header_add_double(hdr, "CD2_1", 0, NULL);
-    fits_header_add_double(hdr, "CD2_2", yscale, NULL);
+    fits_header_add_double(hdr, "CD1_1", cd11, NULL);
+    fits_header_add_double(hdr, "CD1_2", cd12, NULL);
+    fits_header_add_double(hdr, "CD2_1", cd21, NULL);
+    fits_header_add_double(hdr, "CD2_2", cd22, NULL);
     fits_header_add_int(hdr, "IMAGEW", W, NULL);
     fits_header_add_int(hdr, "IMAGEH", H, NULL);
 
@@ -1608,14 +1651,28 @@ anwcs_t* anwcs_create_mollweide(double refra, double refdec,
                                 double zoomfactor,
                                 int W, int H, anbool yflip) {
     return allsky_wcs(refra, refdec, zoomfactor, W, H, yflip,
-                      "MOL", "Mollweide");
+                      "MOL", "Mollweide", FALSE, NULL, NULL, 0.);
 }
 
 anwcs_t* anwcs_create_hammer_aitoff(double refra, double refdec,
                                     double zoomfactor,
                                     int W, int H, anbool yflip) {
     return allsky_wcs(refra, refdec, zoomfactor, W, H, yflip,
-                      "AIT", "Hammer-Aitoff");
+                      "AIT", "Hammer-Aitoff", FALSE, NULL, NULL, 0.);
+}
+
+anwcs_t* anwcs_create_hammer_aitoff_rectangular(double refra, double refdec,
+                                                double zoomfactor, double rotate,
+                                                int W, int H, anbool yflip) {
+    return allsky_wcs(refra, refdec, zoomfactor, W, H, yflip,
+                      "AIT", "Hammer-Aitoff", TRUE, NULL, NULL, rotate);
+}
+
+anwcs_t* anwcs_create_hammer_aitoff_galactic(double ref_long, double ref_lat,
+                                             double zoomfactor,
+                                             int W, int H, anbool yflip) {
+    return allsky_wcs(ref_long, ref_lat, zoomfactor, W, H, yflip,
+                      "AIT", "Hammer-Aitoff", TRUE, "GLON", "GLAT", 0.);
 }
 
 anwcs_t* anwcs_create_cea_wcs(double refra, double refdec,
@@ -1664,6 +1721,75 @@ anwcs_t* anwcs_create_cea_wcs(double refra, double refdec,
     return anwcs;
 }
 
+#ifndef WCSLIB_EXISTS
+#define WCSLIB_HAS_WCSCCS 0
+#endif
+
+int anwcs_galactic_to_radec(anwcs_t* wcs) {
+    if (!wcs) return -1;
+    if (wcs->type != ANWCS_TYPE_WCSLIB) {
+        ERROR("anwcs_galactic_to_radec is only implemented for WCSlib.");
+        return -1;
+    }
+#if WCSLIB_HAS_WCSCCS
+    // Convert from Galactic to RA,Dec basis
+    int rtn;
+    anwcslib_t* anwcslib = wcs->data;
+    rtn = wcsccs(anwcslib->wcs, 192.8595, 27.1283, 122.9319,
+                 "RA", "DEC", "J2000", 2000.0, "");
+    if (rtn) {
+        ERROR("Failed to convert coordinate system with wcsccs()");
+        return rtn;
+    }
+    return 0;
+#else
+    ERROR("WCSLib >= v7.5 is required for anwcs_create_galactic_car_wcs");
+    return -1;
+#endif
+}
+
+anwcs_t* anwcs_create_galactic_car_wcs(double refra, double refdec,
+                                       double refx, double refy,
+                                       double pixscale,
+                                       int W, int H, anbool yflip) {
+    qfits_header* hdr;
+    char* str = NULL;
+    int Nstr = 0;
+    anwcs_t* anwcs = NULL;
+    char code[64];
+    const char* wcsname = "Plate Carree";
+    const char* wcscode = "CAR";
+    hdr = qfits_header_default();
+    sprintf(code, "GLON-%s", wcscode);
+    qfits_header_add(hdr, "CTYPE1", code, wcsname, NULL);
+    sprintf(code, "GLAT-%s", wcscode);
+    qfits_header_add(hdr, "CTYPE2", code, wcsname, NULL);
+    fits_header_add_double(hdr, "CRPIX1", refx, NULL);
+    fits_header_add_double(hdr, "CRPIX2", refy, NULL);
+    fits_header_add_double(hdr, "CRVAL1", refra,  NULL);
+    fits_header_add_double(hdr, "CRVAL2", refdec, NULL);
+    fits_header_add_double(hdr, "CD1_1", -pixscale, NULL);
+    fits_header_add_double(hdr, "CD1_2", 0, NULL);
+    fits_header_add_double(hdr, "CD2_1", 0, NULL);
+    fits_header_add_double(hdr, "CD2_2", pixscale * (yflip ? -1 : 1), NULL);
+    fits_header_add_int(hdr, "IMAGEW", W, NULL);
+    fits_header_add_int(hdr, "IMAGEH", H, NULL);
+    //fits_header_add_double(hdr, "LATPOLE", 0., NULL);
+    //fits_header_add_double(hdr, "LONPOLE", 0., NULL);
+    str = fits_to_string(hdr, &Nstr);
+    qfits_header_destroy(hdr);
+    if (!str) {
+        ERROR("Failed to write %s FITS header as string", wcsname);
+        return NULL;
+    }
+    anwcs = anwcs_wcslib_from_string(str, Nstr);
+    free(str);
+    if (!anwcs) {
+        ERROR("Failed to parse %s header string with wcslib", wcsname);
+        return NULL;
+    }
+    return anwcs;
+}
 
 anwcs_t* anwcs_create_mercator_2(double refra, double refdec,
                                  double crpix1, double crpix2,
